@@ -22,7 +22,6 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #include <TGUI/Loading/Theme.hpp>
 #include <TGUI/Loading/Serializer.hpp>
 #include <TGUI/Widget.hpp>
@@ -260,6 +259,8 @@ namespace tgui
                                                          {"ArrowColorHover", Color::Black},
                                                          {"BorderBetweenArrows", 2.f}})},
                     {"SpinControl", RendererData::create({})},
+                    {"SplitContainer", RendererData::create({{"SplitterColor", Color{60, 60, 60}},
+                                                             {"SplitterColorHover", Color::Black}})},
                     {"TabContainer", RendererData::create({})},
                     {"Tabs", RendererData::create({{"Borders", Borders{1}},
                                                    {"BorderColor", Color::Black},
@@ -338,6 +339,7 @@ namespace tgui
         {"ChildWindow", {{"CloseButton", "Button"}}},
         {"ColorPicker", {{"Button", ""}, {"Label", ""}, {"Slider", ""}}},
         {"ComboBox", {{"ListBox", ""}}},
+        {"EditBoxSlider", {{"EditBox", ""}, {"Slider", ""}}},
         {"FileDialog", {{"Button", ""}, {"EditBox", ""}, {"ListView", ""}, {"FilenameLabel", "Label"}, {"FileTypeComboBox", "ComboBox"}}},
         {"Label", {{"Scrollbar", ""}}},
         {"ListBox", {{"Scrollbar", ""}}},
@@ -504,6 +506,9 @@ namespace tgui
             {"BorderColor", ""},
             {"Borders", ""},
         }},
+        {"SplitContainer", {
+            {"SplitterColor", "BorderColor"},
+        }},
         {"Tabs", {
             {"BackgroundColor", ""},
             {"SelectedBackgroundColor", ""},
@@ -703,14 +708,20 @@ namespace tgui
             }
 
             existingRenderer = newRenderer;
-
-            // Update the existing widgets that were using the previous renderer from this theme
-            for (auto& observer : newRenderer->observers)
-                observer->setRenderer(newRenderer);
-
             ++existingRendererIt;
         }
 
+        // Update the existing widgets that were using the previous renderer from this theme.
+        // We do this in a separate loop because all renderers need to be replaced before
+        // we tell the observers (because e.g. an observer of the BitmapButton renderer might
+        // want to access the Button renderer of the theme to inherit properties).
+        for (auto pair : m_renderers)
+        {
+            const auto& renderer = pair.second;
+            for (auto& observer : renderer->observers)
+                observer->setRenderer(renderer);
+        }
+
         // Add the renderers that only existed in the other renderers (e.g. added via the addRenderer function)
         for (const auto& otherRendererPair : otherTheme.m_renderers)
         {
