@@ -22,7 +22,6 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #include <TGUI/Widgets/ScrollablePanel.hpp>
 #include <TGUI/Vector2.hpp>
 #include <TGUI/Keyboard.hpp>
@@ -64,6 +63,10 @@ namespace tgui
         m_horizontalScrollbar       {other.m_horizontalScrollbar},
         m_verticalScrollbarPolicy   {other.m_verticalScrollbarPolicy},
         m_horizontalScrollbarPolicy {other.m_horizontalScrollbarPolicy},
+        m_verticalScrollAmount      {other.m_verticalScrollAmount},
+        m_horizontalScrollAmount    {other.m_horizontalScrollAmount},
+        m_verticalScrollbarWasVisibleOnSizeUpdate{other.m_verticalScrollbarWasVisibleOnSizeUpdate},
+        m_horizontalScrollbarWasVisibleOnSizeUpdate{other.m_horizontalScrollbarWasVisibleOnSizeUpdate},
         m_connectedPositionCallbacks{},
         m_connectedSizeCallbacks    {}
     {
@@ -84,6 +87,10 @@ namespace tgui
         m_horizontalScrollbar       {std::move(other.m_horizontalScrollbar)},
         m_verticalScrollbarPolicy   {std::move(other.m_verticalScrollbarPolicy)},
         m_horizontalScrollbarPolicy {std::move(other.m_horizontalScrollbarPolicy)},
+        m_verticalScrollAmount      {std::move(other.m_verticalScrollAmount)},
+        m_horizontalScrollAmount    {std::move(other.m_horizontalScrollAmount)},
+        m_verticalScrollbarWasVisibleOnSizeUpdate{std::move(other.m_verticalScrollbarWasVisibleOnSizeUpdate)},
+        m_horizontalScrollbarWasVisibleOnSizeUpdate{std::move(other.m_horizontalScrollbarWasVisibleOnSizeUpdate)},
         m_connectedPositionCallbacks{std::move(other.m_connectedPositionCallbacks)},
         m_connectedSizeCallbacks    {std::move(other.m_connectedSizeCallbacks)}
     {
@@ -109,6 +116,10 @@ namespace tgui
             m_horizontalScrollbar       = other.m_horizontalScrollbar;
             m_verticalScrollbarPolicy   = other.m_verticalScrollbarPolicy;
             m_horizontalScrollbarPolicy = other.m_horizontalScrollbarPolicy;
+            m_verticalScrollAmount      = other.m_verticalScrollAmount;
+            m_horizontalScrollAmount    = other.m_horizontalScrollAmount;
+            m_verticalScrollbarWasVisibleOnSizeUpdate = other.m_verticalScrollbarWasVisibleOnSizeUpdate;
+            m_horizontalScrollbarWasVisibleOnSizeUpdate = other.m_horizontalScrollbarWasVisibleOnSizeUpdate;
 
             disconnectAllChildWidgets();
 
@@ -134,6 +145,10 @@ namespace tgui
             m_horizontalScrollbar       = std::move(other.m_horizontalScrollbar);
             m_verticalScrollbarPolicy   = std::move(other.m_verticalScrollbarPolicy);
             m_horizontalScrollbarPolicy = std::move(other.m_horizontalScrollbarPolicy);
+            m_verticalScrollAmount      = std::move(other.m_verticalScrollAmount);
+            m_horizontalScrollAmount    = std::move(other.m_horizontalScrollAmount);
+            m_verticalScrollbarWasVisibleOnSizeUpdate = other.m_verticalScrollbarWasVisibleOnSizeUpdate;
+            m_horizontalScrollbarWasVisibleOnSizeUpdate = other.m_horizontalScrollbarWasVisibleOnSizeUpdate;
             Panel::operator=(std::move(other));
 
             disconnectAllChildWidgets();
@@ -193,6 +208,9 @@ namespace tgui
 
     void ScrollablePanel::setSize(const Layout2d& size)
     {
+        m_horizontalScrollbarWasVisibleOnSizeUpdate = m_horizontalScrollbar->isShown();
+        m_verticalScrollbarWasVisibleOnSizeUpdate = m_verticalScrollbar->isShown();
+
         Panel::setSize(size);
         updateScrollbars();
     }
@@ -303,9 +321,9 @@ namespace tgui
     Vector2f ScrollablePanel::getInnerSize() const
     {
         Vector2f size = Panel::getInnerSize();
-        if (m_verticalScrollbarPolicy == Scrollbar::Policy::Always)
+        if (m_verticalScrollbar->isShown())
             size.x -= std::min(size.x, getScrollbarWidth());
-        if (m_horizontalScrollbarPolicy == Scrollbar::Policy::Always)
+        if (m_horizontalScrollbar->isShown())
             size.y -= std::min(size.y, getScrollbarWidth());
         return size;
     }
@@ -455,6 +473,13 @@ namespace tgui
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
+    unsigned int ScrollablePanel::getVerticalScrollbarMaxValue() const
+    {
+        return m_verticalScrollbar->getMaxValue();
+    }
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
     void ScrollablePanel::setHorizontalScrollbarValue(unsigned int value)
     {
         m_horizontalScrollbar->setValue(value);
@@ -469,6 +494,13 @@ namespace tgui
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
+    unsigned int ScrollablePanel::getHorizontalScrollbarMaxValue() const
+    {
+        return m_horizontalScrollbar->getMaxValue();
+    }
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
     bool ScrollablePanel::isVerticalScrollbarShown() const
     {
         return m_verticalScrollbar->isShown();
@@ -859,6 +891,13 @@ namespace tgui
 
         if (m_horizontalScrollAmount == 0)
             setHorizontalScrollAmount(0);
+
+        if ((m_horizontalScrollbarWasVisibleOnSizeUpdate != m_horizontalScrollbar->isShown()) || (m_verticalScrollbarWasVisibleOnSizeUpdate != m_verticalScrollbar->isShown()))
+        {
+            m_horizontalScrollbarWasVisibleOnSizeUpdate = m_horizontalScrollbar->isShown();
+            m_verticalScrollbarWasVisibleOnSizeUpdate = m_verticalScrollbar->isShown();
+            recalculateBoundSizeLayouts();
+        }
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
